Coverage Index

Covered: 1648 lines
Missed: 508 lines
Skipped 680 lines
Percent: 76 %

File | Covered | Missed | Skipped | Percent
pylons | 1 | 24 | 10 | 4 %
pylons.i18n.translation | 27 | 115 | 56 | 19 %
pylons.configuration | 44 | 112 | 50 | 28 %
pylons.error | 16 | 16 | 11 | 50 %
pylons.i18n | 1 | 1 | 1 | 50 %
pylons.util | 106 | 60 | 43 | 63 %
pylons.templating | 160 | 72 | 102 | 68 %
pylons.controllers.util | 118 | 33 | 58 | 78 %
pylons.controllers.core | 190 | 28 | 54 | 87 %
pylons.wsgiapp | 212 | 30 | 83 | 87 %
pylons.decorators | 146 | 17 | 45 | 89 %
pylons.controllers | 3 | 0 | 1 | 100 %
pylons.controllers.xmlrpc | 235 | 0 | 65 | 100 %
pylons.decorators.cache | 138 | 0 | 27 | 100 %
pylons.decorators.secure | 80 | 0 | 31 | 100 %
pylons.decorators.util | 15 | 0 | 3 | 100 %
pylons.middleware | 156 | 0 | 40 | 100 %